libpythonpro_gsc

Modulo para exemplificar a construcao de projetos Python no curso Pytools

Neste curso e ensinado como contribuir com projetos de codigos abertos

link do curso do [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://app.travis-ci.com/guisouco/libpythonpro.svg?branch=main)](https://app.travis-ci.com/guisouco/libpythonpro)
[![Updates](https://pyup.io/repos/github/guisouco/libpythonpro/shield.svg)](https://pyup.io/repos/github/guisouco/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/guisouco/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/guisouco/libpythonpro/)

Suportada versao 3 de Python

Para instalar:

``console 
py -3 -m venv .venv 
source .venv\Scripts\activate
pip install -r requirements-dev.txt``


Para conferir qualidade do codigo:

``console
flake8``

Tópicos a serem abrodados: 
1. Git
2. Virtualenv
3. Pip